@@ -53,7 +53,7 @@ private:
     void reposition();
 
 private:
-    OverlayWidgetPrivate *const d;
+    std::unique_ptr<OverlayWidgetPrivate> const d;
 };
 
 class TransactionItemView : public QScrollArea
@@ -87,7 +87,7 @@ class TransactionItem : public QWidget
 public:
     TransactionItem(QWidget *parent, ProgressItem *item, bool first);
 
-    ~TransactionItem();
+    ~TransactionItem() override;
 
     void hideHLine();
 
